==> 0.0.2.tar.gz: lib/widgets/expansionPanelList/custom_expansion_panel_list.dart <==
import 'package:flutter/material.dart';

const double _kPanelHeaderCollapsedHeight = 48.0;
const double _kPanelHeaderExpandedHeight = 64.0;

class CustomExpansionPanelList extends StatelessWidget {
  final List<ExpansionPanel> children;
  final ExpansionPanelCallback? expansionCallback;
  final Duration? animationDuration;

  const CustomExpansionPanelList({
    Key? key,
    required this.children,
    this.expansionCallback,
    this.animationDuration,
  }) : super(key: key);

  bool _isChildExpanded(int index) {
    return children[index].isExpanded;
  }

  bool _isLastChild(int index) {
    return index + 1 == children.length;
  }

  int _expandedIndex() {
    for (var i = 0; i < children.length; i++) {
      ExpansionPanel item = children[i];
      if (item.isExpanded) {
        return i;
      }
    }
    return -1;
  }

  @override
  Widget build(BuildContext context) {
    final List<Widget> items = <Widget>[];
    const EdgeInsets kExpandedEdgeInsets = EdgeInsets.symmetric(
        vertical: _kPanelHeaderExpandedHeight - _kPanelHeaderCollapsedHeight);

    for (int index = 0; index < children.length; index += 1) {
      if (_isChildExpanded(index) &&
          index != 0 &&
          !_isChildExpanded(index - 1)) {
        items.add(
          Divider(
            key: _SaltedKey<BuildContext, int>(context, index * 2 - 1),
            height: 15.0,
            color: Colors.transparent,
          ),
        );
      }

      final Row header = Row(
        children: <Widget>[
          Expanded(
            child: AnimatedContainer(
              duration: animationDuration ?? const Duration(milliseconds: 300),
              curve: Curves.fastOutSlowIn,
              margin: _isChildExpanded(index)
                  ? kExpandedEdgeInsets
                  : EdgeInsets.zero,
              child: SizedBox(
                height: _kPanelHeaderCollapsedHeight,
                child: children[index].headerBuilder(
                  context,
                  children[index].isExpanded,
                ),
              ),
            ),
          ),
          Container(
            margin: const EdgeInsetsDirectional.only(end: 8.0),
            child: ExpandIcon(
              isExpanded: _isChildExpanded(index),
              padding: const EdgeInsets.all(16.0),
              onPressed: (bool isExpanded) {
                if (expansionCallback != null) {
                  expansionCallback!(index, isExpanded);
                }
              },
            ),
          ),
        ],
      );

      // double _radiusValue = _isChildExpanded(index) ? 8.0 : 0.0;
      items.add(
        Container(
          key: _SaltedKey<BuildContext, int>(context, index * 2),
          child: Material(
            elevation: 50.0,
            // borderRadius: BorderRadius.all(Radius.circular(_radiusValue)),
            borderRadius: BorderRadius.only(
              topLeft: Radius.circular(
                  _isChildExpanded(index) || index == 0 || _expandedIndex() == index - 1 ? 5.0 : 0.0),
              topRight: Radius.circular(
                  _isChildExpanded(index) || index == 0 || _expandedIndex() == index - 1 ? 5.0 : 0.0),
              bottomLeft: Radius.circular(
                  _isChildExpanded(index) || _isLastChild(index) || _expandedIndex() == index + 1 ? 5.0 : 0.0),
              bottomRight: Radius.circular(
                  _isChildExpanded(index) || _isLastChild(index) || _expandedIndex() == index + 1 ? 5.0 : 0.0),
            ),
            child: Column(
              children: <Widget>[
                header,
                AnimatedCrossFade(
                  firstChild: Container(height: 0.0),
                  secondChild: children[index].body,
                  firstCurve:
                      const Interval(0.0, 0.6, curve: Curves.fastOutSlowIn),
                  secondCurve:
                      const Interval(0.4, 1.0, curve: Curves.fastOutSlowIn),
                  sizeCurve: Curves.fastOutSlowIn,
                  crossFadeState: _isChildExpanded(index)
                      ? CrossFadeState.showSecond
                      : CrossFadeState.showFirst,
                  duration:
                      animationDuration ?? const Duration(milliseconds: 300),
                ),
              ],
            ),
          ),
        ),
      );

      if (_isChildExpanded(index) && index != children.length - 1) {
        items.add(Divider(
          key: _SaltedKey<BuildContext, int>(context, index * 2 + 1),
          height: 15.0,
        ));
      }
    }

    return Column(
      children: items,
    );
  }
}

class _SaltedKey<S, V> extends LocalKey {
  const _SaltedKey(this.salt, this.value);

  final S salt;
  final V value;

  @override
  bool operator ==(dynamic other) {
    if (other.runtimeType != runtimeType) return false;
    final _SaltedKey<S, V> typedOther = other;
    return salt == typedOther.salt && value == typedOther.value;
  }

  @override
  int get hashCode => hashValues(runtimeType, salt, value);

  @override
  String toString() {
    final String saltString = S == String ? '<\'$salt\'>' : '<$salt>';
    final String valueString = V == String ? '<\'$value\'>' : '<$value>';
    return '[$saltString $valueString]';
  }
}

==> 0.0.4.tar.gz: lib/widgets/expansionPanelList/custom_expansion_panel_list.dart <==
import 'package:flutter/material.dart';

const double _kPanelHeaderCollapsedHeight = 48.0;
const double _kPanelHeaderExpandedHeight = 64.0;

class CustomExpansionPanelListWidget extends StatelessWidget {
  final List<ExpansionPanel> children;
  final ExpansionPanelCallback? expansionCallback;
  final Duration? animationDuration;
  final double? elevation;

  const CustomExpansionPanelListWidget({
    Key? key,
    required this.children,
    this.expansionCallback,
    this.animationDuration,
    this.elevation,
  }) : super(key: key);

  bool _isChildExpanded(int index) {
    return children[index].isExpanded;
  }

  bool _isLastChild(int index) {
    return index + 1 == children.length;
  }

  int _expandedIndex() {
    for (var i = 0; i < children.length; i++) {
      ExpansionPanel item = children[i];
      if (item.isExpanded) {
        return i;
      }
    }
    return -1;
  }

  @override
  Widget build(BuildContext context) {
    final List<Widget> items = <Widget>[];
    const EdgeInsets kExpandedEdgeInsets = EdgeInsets.symmetric(
        vertical: _kPanelHeaderExpandedHeight - _kPanelHeaderCollapsedHeight);

    for (int index = 0; index < children.length; index += 1) {
      if (_isChildExpanded(index) &&
          index != 0 &&
          !_isChildExpanded(index - 1)) {
        items.add(
          Divider(
            key: _SaltedKey<BuildContext, int>(context, index * 2 - 1),
            height: 15.0,
            color: Colors.transparent,
          ),
        );
      }

      final Row header = Row(
        children: <Widget>[
          Expanded(
            child: AnimatedContainer(
              duration: animationDuration ?? const Duration(milliseconds: 300),
              curve: Curves.fastOutSlowIn,
              margin: _isChildExpanded(index)
                  ? kExpandedEdgeInsets
                  : EdgeInsets.zero,
              child: SizedBox(
                height: _kPanelHeaderCollapsedHeight,
                child: children[index].headerBuilder(
                  context,
                  children[index].isExpanded,
                ),
              ),
            ),
          ),
          Container(
            margin: const EdgeInsetsDirectional.only(end: 8.0),
            child: ExpandIcon(
              isExpanded: _isChildExpanded(index),
              padding: const EdgeInsets.all(16.0),
              onPressed: (bool isExpanded) {
                if (expansionCallback != null) {
                  expansionCallback!(index, isExpanded);
                }
              },
            ),
          ),
        ],
      );

      // double _radiusValue = _isChildExpanded(index) ? 8.0 : 0.0;
      items.add(
        Container(
          key: _SaltedKey<BuildContext, int>(context, index * 2),
          child: Material(
            elevation: elevation ?? 50.0,
            // borderRadius: BorderRadius.all(Radius.circular(_radiusValue)),
            borderRadius: BorderRadius.only(
              topLeft: Radius.circular(
                  _isChildExpanded(index) || index == 0 || _expandedIndex() == index - 1 ? 5.0 : 0.0),
              topRight: Radius.circular(
                  _isChildExpanded(index) || index == 0 || _expandedIndex() == index - 1 ? 5.0 : 0.0),
              bottomLeft: Radius.circular(
                  _isChildExpanded(index) || _isLastChild(index) || _expandedIndex() == index + 1 ? 5.0 : 0.0),
              bottomRight: Radius.circular(
                  _isChildExpanded(index) || _isLastChild(index) || _expandedIndex() == index + 1 ? 5.0 : 0.0),
            ),
            child: Column(
              children: <Widget>[
                header,
                AnimatedCrossFade(
                  firstChild: Container(height: 0.0),
                  secondChild: children[index].body,
                  firstCurve:
                      const Interval(0.0, 0.6, curve: Curves.fastOutSlowIn),
                  secondCurve:
                      const Interval(0.4, 1.0, curve: Curves.fastOutSlowIn),
                  sizeCurve: Curves.fastOutSlowIn,
                  crossFadeState: _isChildExpanded(index)
                      ? CrossFadeState.showSecond
                      : CrossFadeState.showFirst,
                  duration:
                      animationDuration ?? const Duration(milliseconds: 300),
                ),
              ],
            ),
          ),
        ),
      );

      if (_isChildExpanded(index) && index != children.length - 1) {
        items.add(Divider(
          key: _SaltedKey<BuildContext, int>(context, index * 2 + 1),
          height: 15.0,
        ));
      }
    }

    return Column(
      children: items,
    );
  }
}

class _SaltedKey<S, V> extends LocalKey {
  const _SaltedKey(this.salt, this.value);

  final S salt;
  final V value;

  @override
  bool operator ==(dynamic other) {
    if (other.runtimeType != runtimeType) return false;
    final _SaltedKey<S, V> typedOther = other;
    return salt == typedOther.salt && value == typedOther.value;
  }

  @override
  int get hashCode => hashValues(runtimeType, salt, value);

  @override
  String toString() {
    final String saltString = S == String ? '<\'$salt\'>' : '<$salt>';
    final String valueString = V == String ? '<\'$value\'>' : '<$value>';
    return '[$saltString $valueString]';
  }
}
